==> pucktrick-0.1.tar.gz: pucktrick-0.1/README.md <==
# pucktrick

Pucktrick is a Python library that provides various utility functions to introduce errors in your dataframe.
The name of library is based on Puck. Puck is the name of the elf in the “A midsummer Night’s dream” of William Shakespeare that is very famous to enjoys causing trouble and playing tricks on mortals and other fairies alike.
  

## Features
pucktrick is organized in modules, one per evary error type

each module inlude function whose name follows this syntax 
errornametypeDataTYpeTypePercentuageOther where 
- errornameType: noisy, inconsitency labels, outlier, 
- DataTYpe: continous, discrete, ….
- Typepercentuage, (New add new error in the dataframe, Extend add more errors in a prexisting dataframe made dirty by pucktrick,  
- Other: eg. fakeValues in case the function add fake values, and so on


## Version
version 0.1

- error type inserted: noisy error and inconsistencylabels


## Installation

You can install pucktrick using pip:

pip install pucktrick

## Usage
to be done

## References

## Contributing
We welcome contributions from the community. To contribute:

Fork the repository
Create a new branch (git checkout -b feature/your-feature)
Commit your changes (git commit -am 'Add new feature')
Push to the branch (git push origin feature/your-feature)
Create a new Pull Request
Please ensure your code adheres to our coding standards and includes appropriate tests.

License
This project is licensed under the Creative Commons Attribution-NonCommercial 4.0 International (CC BY-NC 4.0)  - see the LICENSE file for details.

Acknowledgements
Thanks to the contributors and open-source community for their support.

==> pucktrick-0.4.2.1.tar.gz: pucktrick-0.4.2.1/README.md <==
# pucktrick

Pucktrick is a Python library that provides various utility functions to introduce errors in your dataframe.
The name of library is based on Puck. Puck is the name of the elf in the “A midsummer Night’s dream” of William Shakespeare that is very famous to enjoys causing trouble and playing tricks on mortals and other fairies alike.
  

## Features
pucktrick is organized in modules, one for error type

each module inludes functions whose name follows this syntax 
errornametypeDataTYpeTypePercentuageOther where 
- errornameType: noisy, inconsitency labels, outlier, 
- DataTYpe: continous, discrete, ….
- Typepercentage, (New add new error in the dataframe, Extend add more errors in a prexisting dataframe made dirty by pucktrick,  
- Other: eg. fakeValues in case the function add fake values, and so on



## Version
versione 0.4
 - errortype added: missing values
version  0.3 
 -error type added: duplicated
version 0.2
 - error type inserted: outliers  
version 0.1

- error type inserted: noisy error and inconsistency labels


## Installation

You can install pucktrick using pip:

pip install pucktrick

## Usage
to be done

## References

## Contributing
We welcome contributions from the community. To contribute:

Fork the repository
Create a new branch (git checkout -b feature/your-feature)
Commit your changes (git commit -am 'Add new feature')
Push to the branch (git push origin feature/your-feature)
Create a new Pull Request
Please ensure your code adheres to our coding standards and includes appropriate tests.

License
This project is licensed under the Creative Commons Attribution-NonCommercial 4.0 International (CC BY-NC 4.0)  - see the LICENSE file for details.

Acknowledgements
Thanks to the contributors and open-source community for their support.
